# Pintes
*An amalgamation of horror.*

Pintes is a tool made in Python that allows users to develop static HTML pages with ease.

![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/FormunaGit/Pintes/python-publish.yml?style=flat&logo=githubactions&logoColor=white) ![GitHub License](https://img.shields.io/github/license/FormunaGit/Pintes?logo=gnu) ![GitHub last commit](https://img.shields.io/github/last-commit/formunagit/pintes)

## Why?
- For the actual tool, I have no idea. I had an idea and I worked on it.
- For the name, I also have no idea.

## How?
Pintes internally uses a list that the tag create functions append to. This list is then joined and written to a file after the necessary tags are added.

## Usage
~~As of 0.1:PRERELEASE, Pintes is not on PyPI. And since I don't understand how to use setup.py, you'll have to clone the repository and use the `pintes.py` file as a module.~~

As of 0.2.alpha.1 (0.2a1), Pintes is now on PyPI. You can install it using `pip install pintes` and use it as a module.

Check out the demo folder for a demo on how to use Pintes.
